@@ -64,6 +64,8 @@ describe 'keystone' do
       'rabbit_heartbeat_rate'               => '<SERVICE DEFAULT>',
       'admin_workers'                       => 20,
       'public_workers'                      => 20,
+      'member_role_id'                      => '<SERVICE DEFAULT>',
+      'member_role_name'                    => '<SERVICE DEFAULT>',
       'paste_config'                        => '<SERVICE DEFAULT>',
       'sync_db'                             => true,
       'purge_config'                        => false,
@@ -110,6 +112,8 @@ describe 'keystone' do
       'rabbit_heartbeat_rate'               => '10',
       'rabbit_ha_queues'                    => true,
       'default_domain'                      => 'other_domain',
+      'member_role_id'                      => '123456789',
+      'member_role_name'                    => 'othermember',
       'paste_config'                        => '/usr/share/keystone/keystone-paste.ini',
       'using_domain_config'                 => false
     }
@@ -165,6 +169,8 @@ describe 'keystone' do
        'admin_bind_host',
        'public_port',
        'admin_port',
+       'member_role_id',
+       'member_role_name',
        'debug',
        'use_stderr'
       ].each do |config|
@@ -294,13 +300,6 @@ describe 'keystone' do
       }.to raise_error(RSpec::Expectations::ExpectationNotMetError, /expected that the catalogue would contain Service\[#{platform_parameters[:service_name]}\]/)
     end
 
-    it { is_expected.to contain_class('keystone::service').with(
-      'ensure'          => 'stopped',
-      'service_name'    => platform_parameters[:service_name],
-      'enable'          => false,
-      'validate'        => false
-    )}
-    it { is_expected.to contain_service('httpd').with_before(/Anchor\[keystone::service::end\]/) }
     it { is_expected.to contain_exec('restart_keystone').with(
       'command' => "service #{platform_parameters[:httpd_service_name]} restart",
     ) }
